@@ -191,6 +191,8 @@ class Context(object):
 
         # Get the active profile
         profile = profile or opts_vars.get('profile', None) or metadata.get_active_profile(workspace)
+        if not metadata.active_profile_set(workspace):
+            metadata.set_active_profile(workspace, profile)
         opts_vars['profile'] = profile
 
         # Initialize empty metadata/args
@@ -449,7 +451,8 @@ class Context(object):
 
         self.cached_cmake_prefix_path = ''
         if 'CMAKE_PREFIX_PATH' in sticky_env:
-            split_result_cmake_prefix_path = sticky_env.get('CMAKE_PREFIX_PATH', '').split(':')
+            split_result_cmake_prefix_path = \
+                sticky_env.get('CMAKE_PREFIX_PATH', '').replace('::', ':').strip(':').split(':')
             if len(split_result_cmake_prefix_path) > 1:
                 self.cached_cmake_prefix_path = ':'.join(split_result_cmake_prefix_path[1:])
 
@@ -457,7 +460,7 @@ class Context(object):
         self.env_cmake_prefix_path = ''
         if self.extend_path:
             extended_env = get_resultspace_environment(self.extend_path, quiet=False)
-            self.env_cmake_prefix_path = extended_env.get('CMAKE_PREFIX_PATH', '')
+            self.env_cmake_prefix_path = extended_env.get('CMAKE_PREFIX_PATH', '').replace('::', ':').strip(':')
             if not self.env_cmake_prefix_path:
                 print(clr("@!@{rf}Error:@| Could not load environment from workspace: '{}', "
                           "target environment (env.sh) does not provide 'CMAKE_PREFIX_PATH'").format(self.extend_path))
@@ -466,14 +469,15 @@ class Context(object):
         else:
             # Get the current CMAKE_PREFIX_PATH
             if 'CMAKE_PREFIX_PATH' in os.environ:
-                split_result_cmake_prefix_path = os.environ['CMAKE_PREFIX_PATH'].split(':')
+                split_result_cmake_prefix_path = \
+                    os.environ['CMAKE_PREFIX_PATH'].replace('::', ':').strip(':').split(':')
                 if len(split_result_cmake_prefix_path) > 1 and (
                         (not self.install and split_result_cmake_prefix_path[0] == self.devel_space_abs) or
                         (self.install and split_result_cmake_prefix_path[0] == self.install_space_abs)):
 
                     self.env_cmake_prefix_path = ':'.join(split_result_cmake_prefix_path[1:])
                 else:
-                    self.env_cmake_prefix_path = os.environ.get('CMAKE_PREFIX_PATH', '').rstrip(':')
+                    self.env_cmake_prefix_path = os.environ.get('CMAKE_PREFIX_PATH', '').replace('::', ':').strip(':')
 
         # Add warning for empty extend path
         if (self.devel_layout == 'linked' and
