@@ -316,12 +316,12 @@ class ConsoleStatusController(threading.Thread):
                 abandoneds[jid] = templates['abandoned']
 
         # Combine successfuls and ignoreds, sort by key
-        if len(successfuls) + len(ignoreds) > 0:
+        if len(successfuls) + len(warneds) + len(ignoreds) > 0:
             wide_log("")
             wide_log(clr("[{}] Successful {}:").format(self.label, self.jobs_label))
             wide_log("")
             print_items_in_columns(
-                sorted(itertools.chain(successfuls.items(), ignoreds.items())),
+                sorted(itertools.chain(successfuls.items(), warneds.items(), ignoreds.items())),
                 number_of_columns)
         else:
             wide_log("")
@@ -342,13 +342,6 @@ class ConsoleStatusController(threading.Thread):
             wide_log("")
             print_items_in_columns(sorted(skiplisted.items()), number_of_columns)
 
-        # Print out jobs that failed
-        if len(faileds) > 0:
-            wide_log("")
-            wide_log(clr("[{}] Failed {}:").format(self.label, self.jobs_label))
-            wide_log("")
-            print_items_in_columns(sorted(faileds.items()), number_of_columns)
-
         # Print out jobs that were abandoned
         if len(abandoneds) > 0:
             wide_log("")
@@ -356,6 +349,13 @@ class ConsoleStatusController(threading.Thread):
             wide_log("")
             print_items_in_columns(sorted(abandoneds.items()), number_of_columns)
 
+        # Print out jobs that failed
+        if len(faileds) > 0:
+            wide_log("")
+            wide_log(clr("[{}] Failed {}:").format(self.label, self.jobs_label))
+            wide_log("")
+            print_items_in_columns(sorted(faileds.items()), number_of_columns)
+
         wide_log("")
 
     def print_compact_summary(self, completed_jobs, warned_jobs, failed_jobs):
