@@ -714,9 +714,11 @@ DEVEL_LINK_SKIPLIST = DEVEL_LINK_PREBUILD_SKIPLIST + [
     os.path.join('etc', 'catkin', 'profile.d', '05.catkin-test-results.sh'),
     'env.sh',
     'setup.bash',
+    'setup.fish',
     'setup.zsh',
     'setup.sh',
     'local_setup.bash',
+    'local_setup.fish',
     'local_setup.zsh',
     'local_setup.sh',
     '_setup_util.py',
